#!/usr/bin/env python3

import sys
import math
from astropy.time import Time

DEG = math.pi/180.

def main():

    f = open("AO1.lite", "a")
    f2 = open("jpl.tmp", "w")

    print("# JD (TDB; i.e. uncorrected for LITE) & sigma [arcsec] & pixel_scale [arcsec/pxl] & PNM file & Besselian year & dataset");

    i = 0
    for line in sys.stdin:
        if line[0:1] == "#" or len(line) < 2:
            continue
        l = line.split()

        t1 = Time(l[0] + " " + l[1], format="iso", scale="utc")
        t2 = t1.tdb
        jd = t2.jd
        pnm = l[2]

        i += 1
        sigma = 0.01
        pixel_scale = 3.6e-3

        # lite = d/c * au/day
        lite = 0.0  # it's implemented in the code
        jd = jd - lite

        bessel = 1900.0 + (jd - 2415020.31352) / 365.242198781
        dataset = "SPHERE2018"

        print("%.6f	%f	%f	%d	%s	%.6f	%s" % (jd, sigma, pixel_scale, i, pnm, bessel, dataset))

        f.write("lite = %f d = %f min\n" % (lite, lite*1440.))
        f2.write("'%.8f'\n" % (t1.jd))

    f.close()

if __name__ == "__main__":
    main()


