#!/usr/bin/env python3

import subprocess
import numpy as np
#from astropy.io import fits
from astropy.time import Time

def jd_bessel(jd):
    return 1900.0 + (jd - 2415020.31352) / 365.242198781

def bessel_jd(bessel):
    return (bessel - 1900.0) * 365.242198781 + 2415020.31352

# https://gea.esac.esa.int/archive/documentation/GDR2/Data_processing/chap_cu5pho/sec_cu5pho_calibr/ssec_cu5pho_PhotTransf.html

V = 6.64  # Lupishko (1982)
B_V = 0.70  # Lupishko (1982)

a = -0.02907
b = -0.02385
c = -0.22970
d = -0.001768

def main():

    f = open("22.jdme", "r")

    f2 = open("Lc_V.dat", "w")
    f2.write("# JD (TDB, no lite) & flux_V [mag] & sigma [mag] & dataset & Besselian year (UTC, no lite)\n")

    f3 = open("jpl.tmp", "w")

    i = 0
    for line in f.readlines():
        if line[0:1] == '#': 
            continue
        l = line.split()
        jd = float(l[0])
        mag_G = float(l[1])
        sigma_rel = float(l[2])
        dataset = 9
        datasetstr = "gaia"

        G_V = a + b*B_V + c*B_V**2 + d*B_V**3
        mag_V = mag_G - G_V

        t1 = Time(jd, format="jd", scale="tdb")
        t2 = t1

        bessel = jd_bessel(t1.jd)

        calibration_flux = 1.0
        flux = 10.0**(-0.4*mag_V)*calibration_flux
        sigma_flux = flux*sigma_rel
        sigma_mag = mag_V + 2.5*np.log10((flux+sigma_flux)/calibration_flux)

#        mag = -2.5*np.log10(flux/calibration_flux)

        f2.write("%.8f  %.8f  %.8f  %d  %.8f  %s\n" % (t2.jd, mag_V, sigma_mag, dataset, bessel, datasetstr))
        f3.write("'%.8f'\n" % (t1.jd))
        i += 1

    f.close()
    f2.close()
    f3.close()

if __name__ == "__main__":
    main()




